@@ -18,7 +18,7 @@
 
 """Whole-slide image streamer for machine learning frameworks."""
 
-__version__ = "2.3.2"
+__version__ = "2.3.3"
 
 """
 
@@ -26,4 +26,4 @@ This module supports efficient whole-slide reading and processing for a machine
 execution graph.
 
 """
-from . import configure, codecs
+from . import configure, codecs  # noqa: F401,E402
