@@ -22,12 +22,13 @@ import copy
 import itertools
 import itk
 import large_image
-import large_image_source_tiff as large_image_source
+import large_image_source_tiff
 import math
 import numpy as np
+import os
 import random
 import re
-import scipy
+import scipy.interpolate
 
 
 class _TilesByCommon:
@@ -486,11 +487,7 @@ class TilesByGridAndMask(_TilesByCommon):
                 f' tile_width ({study["tile_width"]}).'
             )
         if mask_filename != "":
-            mask_itk = itk.imread(mask_filename)  # May throw exception
-            if mask_itk.GetImageDimension() != 2:
-                raise ValueError(
-                    f"The mask ({mask_filename}) should be a 2-dimensional image."
-                )
+            mask_itk = self.check_mask_filename(mask_filename)
         if not (
             isinstance(mask_threshold, float)
             and mask_threshold >= 0.0
@@ -587,6 +584,14 @@ class TilesByGridAndMask(_TilesByCommon):
                 random.sample(slide["tiles"].items(), self.randomly_select)
             )
 
+    def check_mask_filename(self, mask_filename):
+        mask_itk = itk.imread(mask_filename)  # May throw exception
+        if mask_itk.GetImageDimension() != 2:
+            raise ValueError(
+                f"The mask ({mask_filename}) should be a 2-dimensional image."
+            )
+        return mask_itk
+
     def compute_from_mask(self, top_left):
         # Check that the input and output aspect ratios are pretty close
         if (
@@ -614,9 +619,8 @@ class TilesByGridAndMask(_TilesByCommon):
         cumulative_mask = np.zeros(
             (self.mask_height + 2, self.mask_width + 2), dtype=np.int64
         )
-        nonzero = np.vectorize(lambda x: int(x != 0))
-        cumulative_mask[1 : self.mask_height + 1, 1 : self.mask_width + 1] = nonzero(
-            itk.GetArrayViewFromImage(self.mask_itk)
+        cumulative_mask[1 : self.mask_height + 1, 1 : self.mask_width + 1] = (
+            itk.GetArrayViewFromImage(self.mask_itk).astype(bool).astype(np.int64)
         )
         cumulative_mask = np.cumsum(np.cumsum(cumulative_mask, axis=0), axis=1)
 
@@ -1038,7 +1042,11 @@ class ChunkLocations(_TilesByCommon):
         # ChunkLocations.read_large_image._num_chunks += 1
 
         # print(f"{chunk_name} begin {datetime.datetime.now()}")
-        ts = large_image_source.open(filename)
+        ts = (
+            large_image_source_tiff.open(filename)
+            if os.path.splitext(filename)[1] in (".tif", ".tiff", ".svs")
+            else large_image.open(filename)
+        )
         chunk = ts.getRegion(
             scale=dict(magnification=returned_magnification),
             format=large_image.constants.TILE_FORMAT_NUMPY,
